@@ -1,6 +1,6 @@
 package Pod::Weaver::Section::Region;
 # ABSTRACT: find a region and put its contents in place where desired
-$Pod::Weaver::Section::Region::VERSION = '4.007';
+$Pod::Weaver::Section::Region::VERSION = '4.008';
 use Moose;
 with 'Pod::Weaver::Role::Section';
 
@@ -9,14 +9,20 @@ use Moose::Autobox;
 #pod =head1 OVERVIEW
 #pod
 #pod This section will find and include a located hunk of Pod.  In general, it will
-#pod find a region with the specified name.
+#pod find a region with the specified name, such as:
+#pod
+#pod   =begin :myfoo
+#pod
+#pod   =head1 More Pod Here
+#pod
+#pod   =end :myfoo
 #pod
 #pod In other words, if your configuration include:
 #pod
 #pod   [Region]
 #pod   region_name = myfoo
 #pod
-#pod ...then this weaver will look for "=begin myfoo" ( and "=for myfoo" and... ) and include
+#pod ...then this weaver will look for "=begin :myfoo" ( and "=for :myfoo" and... ) and include
 #pod it at the appropriate location in your output.
 #pod
 #pod Since you'll probably want to use Region several times, and that will require
@@ -68,6 +74,17 @@ has region_name => (
 #pod
 #pod A boolean value specifying whether nonpod regions are allowed or not. Defaults to false.
 #pod
+#pod C<nonpod> regions are regions I<without> a C<:> prefix as explained in
+#pod L<< perlpodspec|perlpodspec/About Data Paragraphs and "=begin/=end" Regions >>
+#pod
+#pod   # region_name = myregion
+#pod   # is_pod = false
+#pod   =begin myregion
+#pod
+#pod   # region_name = myregion
+#pod   # is_pod = true
+#pod   =begin :myregion
+#pod
 #pod =cut
 
 has allow_nonpod => (
@@ -80,6 +97,16 @@ has allow_nonpod => (
 #pod
 #pod A boolean value specifying whether the region's contents should be flattened or not. Defaults to true.
 #pod
+#pod   #unflattened
+#pod   =begin :myregion
+#pod
+#pod   =head1
+#pod
+#pod   =end :myregion
+#pod
+#pod   #flattened
+#pod   =head1
+#pod
 #pod =cut
 
 has flatten => (
@@ -132,19 +159,25 @@ Pod::Weaver::Section::Region - find a region and put its contents in place where
 
 =head1 VERSION
 
-version 4.007
+version 4.008
 
 =head1 OVERVIEW
 
 This section will find and include a located hunk of Pod.  In general, it will
-find a region with the specified name.
+find a region with the specified name, such as:
+
+  =begin :myfoo
+
+  =head1 More Pod Here
+
+  =end :myfoo
 
 In other words, if your configuration include:
 
   [Region]
   region_name = myfoo
 
-...then this weaver will look for "=begin myfoo" ( and "=for myfoo" and... ) and include
+...then this weaver will look for "=begin :myfoo" ( and "=for :myfoo" and... ) and include
 it at the appropriate location in your output.
 
 Since you'll probably want to use Region several times, and that will require
@@ -174,10 +207,31 @@ The name of this region. Defaults to the plugin name.
 
 A boolean value specifying whether nonpod regions are allowed or not. Defaults to false.
 
+C<nonpod> regions are regions I<without> a C<:> prefix as explained in
+L<< perlpodspec|perlpodspec/About Data Paragraphs and "=begin/=end" Regions >>
+
+  # region_name = myregion
+  # is_pod = false
+  =begin myregion
+
+  # region_name = myregion
+  # is_pod = true
+  =begin :myregion
+
 =head2 flatten
 
 A boolean value specifying whether the region's contents should be flattened or not. Defaults to true.
 
+  #unflattened
+  =begin :myregion
+
+  =head1
+
+  =end :myregion
+
+  #flattened
+  =head1
+
 =head1 AUTHOR
 
 Ricardo SIGNES <rjbs@cpan.org>
